let lib = require('./lib');
let Logger = require('./logger');
let DB = require('./db');
let uuid = require('uuid/v4');
require('dotenv').config();
let serverid = process.env.SERVER_ID || 'undefined';
let batchSize = process.env.BATCH_SIZE || 1;
let url = process.env.LRS_URL || 'http://load.local.veracity.it:3005/xapi';
if (!url.endsWith('/')) {
    url += '/';
}
let username = process.env.LRS_USERNAME || 'tom';
let password = process.env.LRS_PASSWORD || '1234';
let dburl = process.env.DB_URL || 'mongodb://localhost:27017';
let dbname = process.env.DB_NAME || 'loadtest';
let db = new DB(dburl, dbname);
let logger = new Logger(db, serverid, batchSize);
async function setup() {
    await db.connect();
    logger.start();
    process.on('SIGINT', () => {
        console.log("Terminating...");
        logger.stop();
        process.exit(0);
    });
}
async function go() {
    await setup();
    lib.runtest(batchSize, url, username, password, logger);
}
async function populate() {
    let xapi = require("vtc-lrs");
    await setup();
    let lrs = new xapi.LRS();
    let XAPI = new xapi({
        lrs: lrs,
        connectionString: dburl + "/" + process.env.DIRECT_INSERT_DB,
        baseUrl: process.env.host || "http://localhost:3000/xapi"
    });
    lrs.on('ready', function() {
        console.log("The lrs is attached to the database and ready. You can now use the programmatic API.")
        lib.populate(lrs, batchSize, logger);
    })
}
async function directInsert() {
    await setup();
    let MongoClient = require('mongodb').MongoClient;
    let client = await MongoClient.connect(dburl, {
        useNewUrlParser: true
    });
    let collection = client.db(process.env.DIRECT_INSERT_DB).collection("statements");
    try {
        lib.directInsert(collection, batchSize, logger);
    } catch (e) {
        console.log(e);
    }
}
let nohttp = false;
let nodal = false;
for (let i = 0; i < process.argv.length; i++) {
    if (process.argv[i] == "-nohttp") nohttp = true;
    else if (process.argv[i] == "-nodal") nodal = true;
    if (process.argv[i] == "-t" || process.argv[i] == "--tag" && i != process.argv.length) process.env.tag = process.argv[i + 1]
}
if (nohttp) {
    populate();
} else if (nodal) {
    directInsert();
} else {
    go();
}