let request = require('request');
let statements = require('./statements');
let runtest = function(batchSize, url, username, password, logger) {
    let batch = statements.get(batchSize);
    let options = {
        url: url + "statements",
        method: 'POST',
        headers: {
            'X-Experience-API-Version': '1.0.3'
        },
        auth: {
            user: username,
            pass: password
        },
        json: batch,
        time: true,
        forever: true
    };
    request(options, (err, resp, respString) => {
        if (err) {
            logger.error(err, resp)
        }
        if (!err && resp.statusCode !== 200) {
            console.log("Could not post");
            console.log(resp);
            process.exit();
        }
        if (!err) logger.time(resp.timingStart, resp.timingStart + resp.timings.end);
        runtest(batchSize, url, username, password, logger);
    });
};
let uuid = require('uuid');
// Attach the authority, and remove dots. Add other fields as required
const prepForStore = function prepForStore(statement, authority, overrideStored) {
    if (!statement) throw new ClientError('statement is null');
    if (statement.constructor !== Object) {
        throw new ClientError('statement is not Object');
    }
    // Really should never get here.
    if (!statement.id) statement.id = uuid.v4();
    // Store these in the DB as dates, and format on get
    if (!statement.timestamp) statement.timestamp = new Date();
    else statement.timestamp = new Date(statement.timestamp);
    statement.stored = overrideStored || new Date();
    statement.authority = authority;
    //objectWalk(statement, removeDotsInKeys);
    return statement;
};

function statementsToMongoForm(statements) {
    const mongoForm = [];
    for (const i in statements) {
        const statement = statements[i];
        const record = {};
        record.statement = statement;
        record.id = statement.id;
        // Here we are keeping arrays, because these arrays are used to search. The agents array for instance will contain
        // any actor or actor group members, plus the agents from the referenced statement is a statement ref
        // actor and object
        record.agent = [uuid.v4()]; // get the ifis from group and group members
        // lets add an actor.id field. This is just too useful. Remember to scrub it from returned statements
        record.statement.actor.id = record.agent[0];
        record.verb = [statement.verb.id];
        record.activity = [];
        record.registration = [];
        if (statement.context && statement.context.registration) record.registration.push(statement.context.registration);
        // The are indexes used when searching related_agents or related_activities
        record.relatedAgents = [];
        record.relatedActivities = [];
        record.voided = false;
        record.voids = null;
        mongoForm.push(record);
    }
    return mongoForm;
}
let directInsert = function(collection, batchSize, logger) {
    let batch = statements.get(batchSize);
    let hrstart = process.hrtime();
    let startms = (hrstart[0] * 1000) + (hrstart[1] / 1000000);
    if (!batch.map) {
        batch = [batch];
    }
    batch.forEach((i) => {
        prepForStore(i, {
            mbox: "mailto:demo@veracity.com",
            name: "veracity-generated"
        }, false)
    });
    mongoBatch = statementsToMongoForm(batch);
    collection.insert(mongoBatch).then(() => {
        let hrend = process.hrtime();
        let endms = (hrend[0] * 1000) + (hrend[1] / 1000000);
        logger.time(startms, endms);
        directInsert(collection, batchSize, logger);
    }).catch((e) => {
        console.log("There was some problem with the statement.", e);
        console.log(batch);
        process.exit();
    })
}
let populate = function(lrs, batchSize, logger) {
    let batch = statements.get(batchSize);
    let hrstart = process.hrtime();
    let startms = (hrstart[0] * 1000) + (hrstart[1] / 1000000);
    if (batch.map) {
        batch = batch.map((i) => {
            i.authority = {
                mbox: "mailto:demo@veracity.com",
                name: "veracity-generated"
            };
            return i;
        })
    } else {
        batch.authority = {
            mbox: "mailto:demo@veracity.com",
            name: "veracity-generated"
        };
    }
    lrs.insertStatement(batch).then(() => {
        let hrend = process.hrtime();
        let endms = (hrend[0] * 1000) + (hrend[1] / 1000000);

        console.log(batch.length +" in " + (endms - startms))

        logger.time(startms, endms);
        populate(lrs, batchSize, logger);
    }).catch((e) => {
        console.log("There was some problem with the statement.", e);
        console.log(batch);
        process.exit();
    })
}
module.exports = {
    runtest: runtest,
    populate: populate,
    directInsert: directInsert
}