const TIME_BLOCK = 5000; // 1 second (ms)
var os  = require('os-utils');
module.exports = class Logger {
    constructor(db, serverid, batchSize) {
        this.logs = {};
        this.lasttimeread = Math.floor(Date.now()/TIME_BLOCK);
        this.logInterval;
        this.db = db;
        this.serverid = serverid;
        this.batchSize = batchSize;
        this.runid = require('uuid').v4();
    }
    
    start() {
        this.logInterval = setInterval(this.logStats.bind(this), TIME_BLOCK);
    }

    stop() {
        clearInterval(this.logInterval);

        // log the remaining batches
        for (const time in this.logs) {
            if (this.logs.hasOwnProperty(time)) {
                this.logStats(time, this.logs[time]);
            }
        }

        this.db.close();
    }

    logStats (n, s) {
        let stats = s;
        let now = n;
        if (!stats) {
            now = Math.floor(Date.now()/TIME_BLOCK) - 1; //look back a second
            stats = this.logs && this.logs[now];
        }

        if (stats) {




            os.cpuUsage(function(v){
                console.log( 'CPU Usage (%): ' + v * os.cpuCount());
            });
            let count = stats.length;
            let time_avg = +(stats.reduce((p, c) => p + c.total, 0) / count).toFixed(2);

            if (process.env.STATS_TO_CONSOLE) {
                console.log(`${now}: ${count} requests, ${time_avg}ms average`);
            }
            let time = (now * TIME_BLOCK) //keep as timestamp ;
            this.db.save({time: time, server: this.serverid, run:this.runid, posts: count * this.batchSize, roundtrip: time_avg, batchSize: this.batchSize, total:count* this.batchSize,tag:process.env.tag});

            delete this.logs[now];
        }
    }
    
    time (startMS, endMS) {
        // timings.end is relative to timingStart
        //let timingEnd = response.timingStart + response.timings.end;
        let timingEnd = endMS;
        let absTime = Date.now();
        let secondsBatch = Math.floor(absTime/TIME_BLOCK);

        return new Promise((resolve, reject) => {
            let arr = this.logs[secondsBatch] || [];
            arr.push({
                start: startMS,
                total: endMS - startMS
            });
            this.logs[secondsBatch] = arr;
        });
    }

    error (err, response) {
        return new Promise((resolve, reject) => {
            console.log(err);
        });
    }
}