let chance = require('chance').Chance();


let getActor = function () {
    let id = Math.floor(Math.random() * 300000)
    return {
        "mbox" : "mailto:a" + id +"@example.com",
        "name" : `user ${id}`
    }
};

let getDuration = function () {
    return `PT${chance.natural({max: 2})}H${chance.natural({max: 59})}M${chance.natural({max: 59})}S`;
}

let templates = {
    "begin class" : {
        statement : function () {
            let classid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/started",
                    "display": { "en-US": "started" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "duration" : getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "complete class" : {
        statement : function () {
            let classid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/completed",
                    "display": { "en-US": "completed" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "duration" : getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "page view" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/experienced",
                    "display": { "en-US": "experienced" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "duration" : getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "watch video" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let objectid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/viewed",
                    "display": { "en-US": "viewed" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}/${objectid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid} + ${objectid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "listen audio" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let objectid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/listened",
                    "display": { "en-US": "listened" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}/${objectid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid} + ${objectid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "make custom list" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let objectid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/responded",
                    "display": { "en-US": "responded" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "response": objectid,
                    "duration": getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "attempt quiz question" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/attempted",
                    "display": { "en-US": "attempted" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "duration" : getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "select correct quiz answer" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let optionid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/answered",
                    "display": { "en-US": "answered" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}/${optionid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid} + ${optionid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "success" : true
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "select incorrect" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let optionid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/answered",
                    "display": { "en-US": "answered" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}/${optionid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid} + ${optionid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "success" : false
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "input response" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            let objectvar = chance.sentence({words: 3});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/responded",
                    "display": { "en-US": "responded" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "success" : true,
                    "response" : objectvar
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    },
    "passed quiz question" : {
        statement : function () {
            let classid = chance.word({length: 1});
            let slideid = chance.word({length: 1});
            return {
                "actor" : getActor(),
                "verb" : {
                    "id": "http://adlnet.gov/expapi/verbs/passed",
                    "display": { "en-US": "passed" }
                },
                "object" : {
                    "id": `http://texaswic.org/classes/${classid}/${slideid}`,
                    "definition": {
                        "name": {
                            "en-US": `${classid} + ${slideid}`
                        },
                    },
                    "objectType": "Activity"
                },
                "result" : {
                    "success" : true,
                    "duration" : getDuration()
                },
                "timestamp": (new Date()).toISOString()
            }
        }
    }
};

var getOne = function () {
    return chance.pickone(Object.values(templates)).statement();
}

module.exports = {
    get: function (size) {
        if (size > 1) {
            let stmts = [];
            for (size; size > 0; size--) {
                stmts.push(getOne());
            }
            return stmts;
        }
        return getOne();
    }
}