require('dotenv').config(
{
	path: "../.env"
});
let express = require('express');
let app = new express();

let dburl = process.env.DB_URL || 'mongodb://localhost:27017';
let dbname = process.env.DB_NAME || 'loadtest';

let db = new(require("../db.js"))(dburl, dbname);
const COLLECTION = 'postStats';
app.use("/public", express.static("./public"));
let MultilineChart = require("./graphConfigs/multilineChart.js");
app.get('/charts', async function(req, res, next)
{
	try
	{
		let averageSpan = 10; //show every second
		let perSecond = await db.db.collection(COLLECTION).aggregate([
		{
			$group:
			{
				_id:
				{
					time:
					{
						$floor:
						{
							$divide: ["$time", 1000 * averageSpan]
						}
					},
					tag: "$tag"
				},
				statements_per_second:
				{ //average statements per second per minute

					$sum:
					{
						$divide: ["$posts", averageSpan]
					}

				},
				average_ms:
				{
					$avg: "$roundtrip"
				}

			}
		},
		{
			$project:
			{
				_id: "$_id.time",
				statements_per_second: "$statements_per_second",
				average_ms: "$average_ms",
				tag: "$_id.tag"
			}
		},
		{
			$group:
			{
				_id: "$tag",
				average_ms:
				{
					$avg: "$average_ms"
				},
				avg_statements:
				{
					$avg: "$statements_per_second"
				},
				events:
				{
					$push: "$$ROOT"
				}
			}
		}]).toArray();

		let graphs = perSecond.map((i) =>
		{


			let graph = new MultilineChart(["average_ms", "statements_per_second"], "_id");

			graph.dataProvider = i.events;
			graph.titles = [
			{
				text: i._id
			}];
			
			graph.guides = [
			{

				"fillAlpha": 0.10,
				"value": i.average_ms,
				"toValue": i.average_ms,
				valueAxis:"v0"

			},
			{

				"fillAlpha": 0.10,
				"value": i.avg_statements,
				"toValue": i.avg_statements,
				valueAxis:"v1"

			}]
			return graph;
		})



		res.send(graphs);
	}
	catch (e)
	{
		console.log(e);
	}
})

async function go()
{
	await db.connect();
	app.listen(3000)
}
go();