/**
 * Custom plugin that will handle label truncation
 * It will look for property "truncateLabels" in legend settings
 */
AmCharts.addInitHandler(function(chart) {
  if (chart.legend === undefined || chart.legend.truncateLabels === undefined)
    return;
  
  // init fields
  var titleField = chart.titleField;
  var legendTitleField = chart.titleField+"Legend";
  
  // iterate through the data and create truncated label properties
  for(var i = 0; i < chart.dataProvider.length; i++) {
    var label = chart.dataProvider[i][chart.titleField];
    if (label.length > chart.legend.truncateLabels)
      label = label.substr(0, chart.legend.truncateLabels-1)+'...'
      chart.dataProvider[i][legendTitleField] = label;
  }
  
  // replace chart.titleField to show our own truncated field
  chart.titleField = legendTitleField;
  
  // make the balloonText use full title instead
  chart.balloonText = chart.balloonText.replace(/\[\[title\]\]/, "[["+titleField+"]]");
  
}, ["pie"]);